@@ -17,6 +17,17 @@ FACTORY_TEXT_FIELDS = [
 ]
 
 
+class RequiredFactory(object):
+    code_line: str = None
+    app_name: str = None
+    model_name: str = None
+
+    def __init__(self, code_line=None, app_name=None, model_name=None):
+        self.code_line = code_line
+        self.app_name = app_name
+        self.model_name = model_name
+
+
 class FactoryMeta(object):
     """
     Meta data to generate factory for a field.
@@ -26,6 +37,7 @@ class FactoryMeta(object):
     code_line: str = None
     import_libs: [str] = []
     required_models: [str] = []
+    required_factory: RequiredFactory = None
 
     def __init__(self, field=None, model=None):
         self.field = field
@@ -33,6 +45,7 @@ class FactoryMeta(object):
         self.code_line = None
         self.import_libs = []
         self.required_factories = []
+        self.required_factory = None
 
     def generate_code(self):
         field_name = self.field.name
@@ -142,6 +155,11 @@ class FactoryMeta(object):
     def add_required_factory(self, app_name, model_name):
         import_line = 'from {}.factories import {}Factory' \
             .format(app_name, model_name)
+        self.required_factory = RequiredFactory(
+            app_name=app_name,
+            model_name=model_name,
+            code_line=import_line,
+        )
 
         if import_line not in self.required_factories:
             self.required_factories.append(import_line)
