@@ -2,7 +2,9 @@ __all__ = ['FACTORY_VIEW', 'FACTORIES_VIEW', 'FACTORY_INIT']
 
 FACTORIES_VIEW = """{% for required_lib in app_config.factory_required_libs %}{{ required_lib }}
 {% endfor %}
-{% for required_module in app_config.factory_required_modules %}{{ required_module }}
+{% for required_module in app_config.factory_required_modules %}from {{ required_module.app_name }}.factories import ({% for model_name in required_module.model_names %}
+    {{ model_name }}Factory,{% endfor %}
+)
 {% endfor %}
 from drf_core import factories
 from {{ app_name }}.models import ({% for model in models %}
